<?php
namespace admin\view;

class Users
{
  public static function drawLoginForm()
  {
    $tpl = new \Savant3;
    return $tpl -> fetch( 'other/login-form' );
  }
  
  public function editAdmin( $id = '' )
  {
    $id ? $value = 'Zapisz': $value = 'Dodaj';
    
    $out = \admin\view\PagePanel::show( false, $value, true, 'Administratorzy' );

    $dbedit = new \DataEdit( 'pp_users', 'id', $id );
    $dbedit -> addPosition('login', 'Login', 'text');
    $dbedit -> addPosition('name', 'Imię', 'text');
    $dbedit -> addPosition('surname', 'Nazwisko', 'text');
    $dbedit -> addPosition('enabled', 'Aktywny', 'radio', '', \System::getComboYesNo());
    $dbedit -> addPositionHidden('admin', '1');
    $dbedit -> addPositionPassword();
    $out .= $dbedit->draw();

    return $out;
  }
  
  public function showAdmins()
  {
    $out = \admin\view\PagePanel::show( true, false, false, 'Administratorzy' );

    $dbrowse = new \DataBrowse( 'pp_users', 'admin = "1" AND login != "Vampirius"' );
    $dbrowse -> addPosition( 'login',   'Login',    '', '', '', 'login' );
    $dbrowse -> addPosition( 'name',    'Imię',     '', '', '', 'name' );
    $dbrowse -> addPosition( 'surname', 'Nazwisko', '', '', '', 'surname' );
    $dbrowse -> addPosition( 'enabled', 'Aktywny',  '', \System::getComboYesNo() );
    $dbrowse -> addPositionSimple( 'edytuj',  '', './?rw=edit' );
    $dbrowse -> addPositionSimple( 'usuń',    '', '', \System::deleteAction() );
    $dbrowse -> setParam( 'id' );
    $dbrowse -> addSort( 'id ASC' );
    $dbrowse -> addLp();
    $dbrowse -> addFiltr( 'login',    'Login' );
    $dbrowse -> addFiltr( 'enabled',  'Aktywny', \System::getComboYesNo() );
    $out .= $dbrowse -> draw();

    return $out;
  }
  
	public function showUsers()
	{
		$out = \admin\view\PagePanel::show( true, false, false, 'Użytkownicy'  );

		$dbrowse = new \DataBrowse( 'pp_users', 'admin = "0"' );
		$dbrowse -> addPosition( 'login',   'Login',    '', '', '', 'login' );
    $dbrowse -> addPosition( 'name',    'Imię',     '', '', '', 'name' );
    $dbrowse -> addPosition( 'surname', 'Nazwisko', '', '', '', 'surname' );
    $dbrowse -> addPosition( 'enabled', 'Aktywny',  '', \System::getComboYesNo() );
		$dbrowse -> addPositionSimple( 'edytuj',  '', './?rw=edit' );
		$dbrowse -> addPositionSimple( 'usuń',    '', '', \System::deleteAction() );
		$dbrowse -> setParam( 'id' );
		$dbrowse -> addSort( 'id ASC' );
		$dbrowse -> addLp();
		$dbrowse -> addFiltr( 'login',    'Login' );
    $dbrowse -> addFiltr( 'enabled',  'Aktywny', \System::getComboYesNo() );
		$out .= $dbrowse -> draw();

		return $out;
	}

	public function editUser( $id = '' )
	{
		$id ? $value = 'Zapisz' : $value = 'Dodaj';

		$out = \admin\view\PagePanel::show( false, $value, true, 'Użytkownicy' );

		$dbedit = new \DataEdit( 'pp_users', 'id', $id );
		$dbedit -> addPosition( 'login',    'Login',    'text' );
    $dbedit -> addPosition( 'name',     'Imię',     'text' );
    $dbedit -> addPosition( 'surname',  'Nazwisko', 'text' );
    $dbedit -> addPosition( 'enabled',  'Aktywny',  'radio', '', \System::getComboYesNo() );
		$dbedit -> addPositionHidden( 'admin', '0' );
		$dbedit -> addPositionPassword();
		$out .= $dbedit -> draw();

		return $out;
	}
}
?>
