<?php
//po poprawkach
namespace admin\controls;

class Users {
  
  public function getContentAdmins()
  {
    $rw = \System::formGet( 'rw' );

    if ( $rw == 'add' )
      return \admin\view\Users::editAdmin();
    
    if ( $rw == 'edit' )
      return \admin\view\Users::editAdmin( \System::formGetInt( 'id' ) );
    
    if ( $rw == 'del' )
			\admin\factory\Users::deleteAdmin( \System::formGetInt( 'id' ) );
    
		return \admin\view\Users::showAdmins();
  }

  public function getContentUsers()
  {
    $rw = \System::formGet( 'rw' );

    if ( $rw == 'add' )
      return \admin\view\Users::editUser();
    
    if ( $rw == 'edit' )
      return \admin\view\Users::editUser( \System::formGetInt( 'id' ) );
    
    if ( $rw == 'del' )
      \admin\factory\Users::deleteUser( \System::formGetInt( 'id' ) );
    
    return \admin\view\Users::showUsers();
  }
}
?>
